==> alipay-sdk-python-3.7.708.tar.gz: alipay-sdk-python-3.7.708/alipay/aop/api/response/ZhimaCreditPeVisaReportQueryResponse.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeVisaReportQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeVisaReportQueryResponse, self).__init__()
        self._report_apply_status = None
        self._report_content_files = None
        self._user_permit_status = None

    @property
    def report_apply_status(self):
        return self._report_apply_status

    @report_apply_status.setter
    def report_apply_status(self, value):
        self._report_apply_status = value
    @property
    def report_content_files(self):
        return self._report_content_files

    @report_content_files.setter
    def report_content_files(self, value):
        if isinstance(value, list):
            self._report_content_files = list()
            for i in value:
                self._report_content_files.append(i)
    @property
    def user_permit_status(self):
        return self._user_permit_status

    @user_permit_status.setter
    def user_permit_status(self, value):
        self._user_permit_status = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeVisaReportQueryResponse, self).parse_response_content(response_content)
        if 'report_apply_status' in response:
            self.report_apply_status = response['report_apply_status']
        if 'report_content_files' in response:
            self.report_content_files = response['report_content_files']
        if 'user_permit_status' in response:
            self.user_permit_status = response['user_permit_status']

==> alipay-sdk-python-3.7.826.tar.gz: alipay-sdk-python-3.7.826/alipay/aop/api/response/ZhimaCreditPeVisaReportQueryResponse.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeVisaReportQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeVisaReportQueryResponse, self).__init__()
        self._name_spell = None
        self._passport_no = None
        self._report_apply_status = None
        self._report_content_files = None
        self._user_permit_status = None
        self._valid_time = None

    @property
    def name_spell(self):
        return self._name_spell

    @name_spell.setter
    def name_spell(self, value):
        self._name_spell = value
    @property
    def passport_no(self):
        return self._passport_no

    @passport_no.setter
    def passport_no(self, value):
        self._passport_no = value
    @property
    def report_apply_status(self):
        return self._report_apply_status

    @report_apply_status.setter
    def report_apply_status(self, value):
        self._report_apply_status = value
    @property
    def report_content_files(self):
        return self._report_content_files

    @report_content_files.setter
    def report_content_files(self, value):
        if isinstance(value, list):
            self._report_content_files = list()
            for i in value:
                self._report_content_files.append(i)
    @property
    def user_permit_status(self):
        return self._user_permit_status

    @user_permit_status.setter
    def user_permit_status(self, value):
        self._user_permit_status = value
    @property
    def valid_time(self):
        return self._valid_time

    @valid_time.setter
    def valid_time(self, value):
        self._valid_time = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeVisaReportQueryResponse, self).parse_response_content(response_content)
        if 'name_spell' in response:
            self.name_spell = response['name_spell']
        if 'passport_no' in response:
            self.passport_no = response['passport_no']
        if 'report_apply_status' in response:
            self.report_apply_status = response['report_apply_status']
        if 'report_content_files' in response:
            self.report_content_files = response['report_content_files']
        if 'user_permit_status' in response:
            self.user_permit_status = response['user_permit_status']
        if 'valid_time' in response:
            self.valid_time = response['valid_time']
